@@ -1,7 +1,6 @@
-from django.urls import path, include, reverse
-from django.utils.translation import ugettext_lazy as _
+from django.urls import include, path, reverse
+from django.utils.translation import gettext_lazy as _
 from django.views.i18n import JavaScriptCatalog
-
 from wagtail.admin.menu import MenuItem
 from wagtail.core import hooks
 
@@ -11,9 +10,13 @@ from . import views
 @hooks.register("register_admin_urls")
 def register_admin_urls():
     urls = [
-        path("/", views.dashboard, name="dashboard"),
+        path("", views.dashboard, name="dashboard"),
         path("force-sync/", views.force_sync, name="force_sync"),
-        path('jsi18n/', JavaScriptCatalog.as_view(packages=['wagtail_localize_git']), name='javascript_catalog'),
+        path(
+            "jsi18n/",
+            JavaScriptCatalog.as_view(packages=["wagtail_localize_git"]),
+            name="javascript_catalog",
+        ),
     ]
 
     return [
